@@ -14,10 +14,12 @@ import clr
 clr.AddReference('pyWebBrowser/WebBrowser/webBrowser')
 import webBrowser
 
+from pyWebBrowser.Commons import JD
+
 __title__ = 'pyWebBrowser'
 __description__ = '基于 C# 开发的浏览器控制工具。整合提供了浏览器控制、键鼠控制、屏幕截图、剪切板控制等常用 API'
 __url__ = 'https://gitee.com/Yogurt_cry/pyWebBrowser'
-__version__ = 'v2.0.2'
+__version__ = 'v2.1.0'
 __build__ = ''
 __author__ = 'Yogurt_cry'
 __author_email__ = 'ben.2001@foxmail.com'
@@ -246,3 +248,25 @@ class Clipboard:
         :return 当前剪切板的文本数据
         '''
         return self.__clipboard.Get()
+
+class Common:
+    def __init__(self):
+        self = self
+    
+    def JDBusinessBGLogin(self, pattern: dict):
+        '''
+        JD 商家后台登录
+        :param pattern: 登录参数。必填, 且格式必须正确。
+                        screenWidth  : 屏幕宽度
+                        screenHeight : 屏幕高度
+                        browserWidth : 浏览器宽度
+                        browserHeight: 浏览器高度
+                        loginName    : 登录名
+                        loginPassword: 登录密码
+                        browserObj   : 浏览器对象。仅支持 pyWebBrowser.Browser()
+                        screenshotObj: 屏幕截图对象。仅支持 pyWebBrowser.Screenshot()
+                        mouseObj     : 鼠标控制对象。仅支持 pyWebBrowser.Mouse()
+                        keyboardObj  : 键盘控制对象。仅支持 pyWebBrowser.Keyboard()
+                        clipboardObj : 剪切板对象。仅支持 pyWebBrowser.Clipboard()
+        '''
+        JD.BusinessBG().Login(pattern)
